=======
Credits
=======

Development Lead
----------------

* Mojtaba Sardarmehni <msardar2@ncsu.edu>
* Dr. James W. Levis <jwlevis@ncsu.edu> <https://www.ccee.ncsu.edu/people/jwlevis/>

Contributors
------------
* Prof. Morton Barlaz <barlaz@ncsu.edu>
* Prof. Ranji Ranjithan <ranji@ncsu.edu>
* Dr. Joe DeCarolis <jfdecaro@ncsu.edu>



Acknowledgements
----------------
This work was supported by the National Science Foundation(Awards Numbers: `CBET-1437498`_ and  `CBET-1034059`_) and  Environmental Research and Educational Foundation (`EREF`_). 

.. _CBET-1437498: https://nsf.gov/awardsearch/showAward?AWD_ID=1437498
.. _CBET-1034059: https://nsf.gov/awardsearch/showAward?AWD_ID=1034059
.. _EREF: https://erefdn.org/
